Crate rs_ints2uniq2arrow

Crate rs_ints2uniq2arrow 

Re-exports

pub use arrow;

Modules

fs

Functions

ints2uniq2arrow_bt
ints2uniq2arrow_bt8
Creates an array of unique integers from the integers.
ints2uniq2arrow_bt16
Creates an array of unique integers from the integers.
ints2uniq2arrow_bt32
Creates an array of unique integers from the integers.
ints2uniq2arrow_bt64
Creates an array of unique integers from the integers.
ints2uniq_bt
rints2uniq2arrow_bt
rints2uniq2arrow_bt8
Tries to create an array of unique integers from the integers.
rints2uniq2arrow_bt16
Tries to create an array of unique integers from the integers.
rints2uniq2arrow_bt32
Tries to create an array of unique integers from the integers.
rints2uniq2arrow_bt64
Tries to create an array of unique integers from the integers.
rints2uniq_bt
ruints2uniq2arrow_bt8
Tries to create an array of unique integers from the integers.
ruints2uniq2arrow_bt16
Tries to create an array of unique integers from the integers.
ruints2uniq2arrow_bt32
Tries to create an array of unique integers from the integers.
ruints2uniq2arrow_bt64
Tries to create an array of unique integers from the integers.
uints2uniq2arrow_bt8
Creates an array of unique integers from the integers.
uints2uniq2arrow_bt16
Creates an array of unique integers from the integers.
uints2uniq2arrow_bt32
Creates an array of unique integers from the integers.
uints2uniq2arrow_bt64
Creates an array of unique integers from the integers.
uniq2arrow_bt